FadeEffect class

Inheritance

Constructors

FadeEffect({double opacity = 0.8, bool snap = true, AnimationType type = AnimationType.animateOut})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
opacity → double
Opacity determines how faded the item becomes. Higher numbers results to more fading.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snap → bool
Snap back to original opacity when not scrolling Only effective on the AnimatedItem
final
type → AnimationType
Animation type
final

Methods

buildEffect({required Widget child, required int index, required double position, double? itemWidth, double? itemHeight, bool? isScrolling, required AnimationScrollDirection direction}) → Widget
override
isStatic(double delta, AnimationType type, AnimationScrollDirection direction, [bool snap = true, bool? isScrolling]) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited